==> qtjambi-datavisualization-5.15.17-sources.jar: io/qt/datavis/QBarDataArray.java <==
package io.qt.datavis;

import io.qt.*;


/**
 * <p>Template class that provides lists</p>
 * <p>Java wrapper for Qt class <code><a href="http://doc.qt.io/qt-5/qlist.html">QtDataVisualization::QBarDataArray</a></code></p>
 */
public class QBarDataArray extends io.qt.core.QList<io.qt.datavis.@Nullable QBarDataRow>
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>QtDataVisualization::QBarDataArray::<wbr>QBarDataArray()</code></p>
     */
    public QBarDataArray(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QBarDataArray instance);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QBarDataArray(QPrivateConstructor p) { super(p); } 
    

    /**
     * Returns the objects's hash code computed by <code>qHash(QtDataVisualization::QBarDataArray)</code>.
     */
    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QBarDataArray clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QBarDataArray clone_native(long __this_nativeId);
}

==> qtjambi-datavisualization-6.5.2-sources.jar: io/qt/datavis/QBarDataArray.java <==
package io.qt.datavis;

import io.qt.*;


/**
 * <p>Template class that provides a dynamic array</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qlist.html">QBarDataArray</a></code></p>
 */
public class QBarDataArray extends io.qt.core.QList<io.qt.datavis.@Nullable QBarDataRow>
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>QBarDataArray::<wbr>QBarDataArray()</code></p>
     */
    public QBarDataArray(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QBarDataArray instance);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QBarDataArray(QPrivateConstructor p) { super(p); } 
    

    /**
     * Returns the objects's hash code computed by <code>qHash(QBarDataArray)</code>.
     */
    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QBarDataArray clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QBarDataArray clone_native(long __this_nativeId);
}
